==> nocc-1.8.1.tbz: www/nocc/lang/gsw.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: gsw.php 1931 2009-07-05 11:07:47Z gerundt $
 */

/** Swiss German (Alemannisch)
 *
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Als-Holder
 */

$lang_locale = 'gsw_DE.UTF-8';
$default_date_format = '%d.%m.%Y';
$no_locale_date_format = '%d.%m.%Y';
$default_time_format = '%H:%M';
$err_user_empty = 'Kei Benutzername yygee';
$err_passwd_empty = 'Kei Passwort yygee';
$alt_delete = 'Markierti Nochrichte lesche';
$alt_delete_one = 'Nochricht lesche';
$alt_new_msg = 'Neji Nochrichte';
$alt_reply = 'Antwort an dr Absänder';
$alt_reply_all = 'Antwort an alli';
$alt_forward = 'Wyterleitig';
$alt_next = 'Negschti';
$alt_prev = 'Vorigi';
$title_next_page = 'Negschti Syte';
$title_prev_page = 'Vorigi Syte';
$title_next_msg = 'Negschti Nochricht';
$title_prev_msg = 'Vorigi Nochricht';
$html_on = 'an';
$html_theme_label = 'Thema:';
$html_welcome = 'Willchu bi %1$s';
$html_login = 'Aamälde';
$html_passwd = 'Passwort';
$html_submit = 'Jo';
$html_help = 'Hilf';
$html_server = 'Server';
$html_wrong = 'Dr Benutzername oder s Passwort sin falsch';
$html_retry = 'Nomol';
$html_remember = 'Yystellige spychere';
$html_lang_label = 'Sproch:';
$html_msgperpage_label = 'Nochrichte pro Syte:';
$html_preferences = 'Yystellige';
$html_full_name_label = 'Vollständige Name:';
$html_email_address_label = 'E-Mail-Adräss:';
$html_ccself = 'Kopii vu dr Nochrichte an di eige Adräss schicke';
$html_hide_addresses = 'Adrässe verstecke';
$html_outlook_quoting = 'Quoting im Outlook-Stil';
$html_reply_to = 'Antwort an';
$html_use_signature = 'Signatur verwände';
$html_signature = 'Signatur';
$html_signature_label = 'Unterschrift:';
$html_reply_leadin_label = 'Antwort-Yyleitig:';
$html_prefs_updated = 'Yystellige gspycheret';
$html_manage_folders_link = 'IMAP-Ordner verwalte';
$html_manage_filters_link = 'E-Mail-Filter verwalte';
$html_use_graphical_smilies = 'Graphischi Emoticons verwände';
$html_sent_folder_label = 'Kopier di verschickt E-Mail in s Verzeichnis, wu aagee isch:';
$html_trash_folder_label = 'Gleschti Mail in dr Ordner verschiebe, wu aagee isch:';
$html_colored_quotes = 'Farbigi Zitat';
$html_display_struct = 'Strukturierte Täkscht aazeige';
$html_send_html_mail = 'E-Mail im HTML-Format verschicke';
$html_folders = 'Ordner';
$html_folders_create_failed = 'Dr Ordner het nit chenne aagleit wäre!';
$html_folders_sub_failed = 'Dr Ordner het nit chenne abonniert wäre!';
$html_folders_unsub_failed = 'Dr Ordner het nit chenne abbstellt wäre!';
$html_folders_rename_failed = 'Dr Ordner het nit chenne umgnännt wäre!';
$html_folders_updated = 'D Ordner sin aktualisiert wore';
$html_folder_subscribe = 'Abonniere';
$html_folder_rename = 'Umnänne:';
$html_folder_create = 'Neje Ordner aalege';
$html_folder_remove = 'Abbstelle:';
$html_folder_delete = 'Lesche';
$html_folder_to = 'no';
$html_filter_remove = 'Lesche';
$html_filter_body = 'Nochrichtetäkscht';
$html_filter_subject = 'Beträff';
$html_filter_to = 'Empfängerfäld (To)';
$html_filter_cc = 'Cc-Fäld';
$html_filter_from = 'Absänderfäld (From)';
$html_filter_change_tip = 'Go ne Filter ändere chasch dää eifach iberschrybe.';
$html_reapply_filters = 'Alli Filter nomol aawände';
$html_filter_contains = 'beinhaltet';
$html_filter_name = 'Filter Name';
$html_filter_action = 'Filter Aktion';
$html_filter_moveto = 'Verschiebe no';
$html_select_one = '--Uuswehle--';
$html_and = 'Un';
$html_new_msg_in = 'Neji Nochrichte in';
$html_or = 'oder';
$html_move = 'Verschiebe';
$html_copy = 'Kopiere';
$html_messages_to = 'di markierte Nochrichte no';
$html_gotopage = 'Gang uf d Syte';
$html_gotofolder = 'Gang zum Ordner';
$html_other_folders = 'Ordner Lischt';
$html_page = 'Syte';
$html_of = 'vu';
$html_view_header = 'Header aazeige';
$html_remove_header = 'Header verstecke';
$html_inbox = 'Poschtyygang';
$html_new_msg = 'Schrybe';
$html_reply = 'Antwort gee';
$html_reply_short = 'Re:';
$html_reply_all = 'Antwort an alli';
$html_forward = 'Wyterleitig';
$html_forward_short = 'Fwd:';
$html_forward_info = 'D Nochricht, wu soll wytergleitet wäre, wird mit däre E-Mail as Aahang verschickt.';
$html_delete = 'Lesche';
$html_new = 'Nej';
$html_mark = 'Lesche';
$html_att_label = 'Aahang:';
$html_atts_label = 'Aahäng';
$html_att_unknown = '[nit bekannt]';
$html_attach = 'Aahänke';
$html_attach_forget = 'Du muesch d Datei vo em Verschicke vu dr Nochicht aahänke !';
$html_attach_delete = 'Uusgwehlti uuseneh';
$html_attach_none = 'As Aahang muesch e Datei uuswehle!';
$html_sort_by = 'Sortiere no';
$html_sort = 'Sortiere';
$html_from = 'Vu';
$html_from_label = 'Vu:';
$html_subject = 'Beträff';
$html_subject_label = 'Betreff:';
$html_date = 'Datum';
$html_date_label = 'Datum:';
$html_sent = 'Gschickt:';
$html_wrote = 'het gschribe';
$html_size = 'Greßi';
$html_totalsize = 'Gsamtgreßi';
$html_kb = 'kB';
$html_mb = 'MB';
$html_gb = 'GB';
$html_bytes = 'Byte';
$html_filename = 'Dateiname';
$html_to = 'An';
$html_to_label = 'An:';
$html_cc = 'Kopii';
$html_cc_label = 'Cc:';
$html_bcc_label = 'Bcc:';
$html_nosubject = 'Kei Beträff';
$html_send = 'Schicke';
$html_cancel = 'Abbräche';
$html_no_mail = 'Kei neji Nochrichte.';
$html_logout = 'Abmälde';
$html_msg = 'Nochricht';
$html_msgs = 'Nochrichte';
$html_configuration = 'Dää Server isch nit richtig konfiguriert!';
$html_priority = 'Priorität';
$html_priority_label = 'Priorität:';
$html_lowest = 'Seli nider';
$html_low = 'Nider';
$html_normal = 'Normal';
$html_high = 'Hoch';
$html_highest = 'Seli hoch';
$html_receipt = 'Läsebstätigung aafordere';
$html_select = 'Uuswahl';
$html_select_all = 'Uuswahl umdrille';
$html_loading_image = 'Am Bild lade';
$html_send_confirmed = 'Dyy Mail isch verschickt wore.';
$html_no_sendaction = 'Kei Aktion aagee. Schalt JavaScript yy un versuech s drno nomol.';
$html_error_occurred = 'S het e Fähler gee';
$html_prefs_file_error = 'Cha d Yystellige-Datei nit Ufmache zum Schrybe.';
$html_wrap = 'Zahl vu Zeiche, wu di verschickte Nochrichte derno umbroche wäre:';
$html_wrap_none = 'Kei Umbruch';
$html_usenet_separator = 'Usenet-Signaturtränner ("-- \n") verwände';
$html_mark_as = 'Markier as';
$html_read = 'gläse';
$html_unread = 'nit gläse';
$html_encoding_label = 'Zeichesatz-Kodierig:';
$html_add = 'Zuefiege';
$html_contacts = 'Kontakt vu %1$s';
$html_modify = 'Ändere';
$html_back = 'Zruck';
$html_contact_add = 'Neje Kontakt dezuefiege';
$html_contact_mod = 'E Kontakt ändere';
$html_contact_first = 'Vorname';
$html_contact_last = 'Nochname';
$html_contact_nick = 'Ibername';
$html_contact_mail = 'E-Mail-Adräss';
$html_contact_list = 'Kontaktlischt vu %1$s';
$html_contact_del = 'vu dr Kontaktlischt';
$html_contact_count = '%1$d Kontakt';
$html_contact_err1 = 'D Maximalaazahl vu dr Kontakt isch „%1$d“';
$html_contact_err2 = 'Du chasch kei neje Kontakt dezuefiege';
$html_contact_err3 = 'Du hesch nit s Rächt, uf d Kontaktlischt zuezgryfe';
$html_contact_none = 'Kei Kontakt gfunde.';
$html_del_msg = 'Solle di markierte Nochrichte glescht wäre?';
$html_down_mail = 'Abelade';
$original_msg = '-- Urspringligi Nochricht --';
$to_empty = 'S \'An\'-Fäld derf nit läär syy !';
$html_images_warning = 'Zue Dyynere Sicherheit wäre externi Bilder nit aazeigt.';
$html_images_display = 'Bilder aazeige';
$html_smtp_error_no_conn = 'Het d Verbindung nit chenne ufmache';
$html_smtp_error_unexpected = 'SMTP-Antwort, wu nit erwartet woren isch:';
$lang_could_not_connect = 'Verbindig zum Server fählgschlaa';
$lang_invalid_msg_num = 'Fählerhafti Nochrichte-Nummere';
$html_file_upload_attack = 'D Datei, wu ufeglade woren isch, het nit chenne gfunde wäre';
$html_invalid_email_address = 'Nit giltigi E-Mail-Adräss';
$html_invalid_msg_per_page = 'Nit giltigi Aazahl vu Nochrichte pro Syte.';
$html_invalid_wrap_msg = 'Nit giltige Nochrichtenumbruch';
$html_seperate_msg_win = 'Nochricht in eme neje Fänschter ufmache';
$html_err_file_contacts = 'Cha d Kontaktdatei nit zum Schryben ufmache.';
$html_session_file_error = 'Cha d Sitzigsdatei nit zum Schryben ufmache.';
$html_login_not_allowed = 'Die Aamäldig isch nit zuegloo fir e Verbindig.';
$lang_err_send_delay = 'Du muesch zwische zwoo Mails warte (%1$d seconds)';
$html_search = 'Sueche';

==> nocc-1.8.3.tbz: www/nocc/lang/gsw.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: gsw.php 2181 2010-04-27 09:07:03Z gerundt $
 */

/** Swiss German (Alemannisch)
 *
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Als-Holder
 */

$lang_locale = 'gsw_DE.UTF-8';
$default_date_format = '%d.%m.%Y';
$no_locale_date_format = '%d.%m.%Y';
$default_time_format = '%H:%M';
$err_user_empty = 'Kei Benutzername yygee';
$err_passwd_empty = 'Kei Passwort yygee';
$alt_delete = 'Markierti Nochrichte lesche';
$alt_delete_one = 'Nochricht lesche';
$alt_new_msg = 'Neji Nochrichte';
$alt_reply = 'Antwort an dr Absänder';
$alt_reply_all = 'Antwort an alli';
$alt_forward = 'Wyterleitig';
$alt_next = 'Negschti';
$alt_prev = 'Vorigi';
$title_next_page = 'Negschti Syte';
$title_prev_page = 'Vorigi Syte';
$title_next_msg = 'Negschti Nochricht';
$title_prev_msg = 'Vorigi Nochricht';
$html_theme_label = 'Thema:';
$html_welcome = 'Willchu bi %1$s';
$html_login = 'Aamälde';
$html_user_label = 'Benutzer:';
$html_passwd_label = 'Passwort:';
$html_submit = 'Jo';
$html_help = 'Hilf';
$html_server_label = 'Server:';
$html_wrong = 'Dr Benutzername oder s Passwort sin falsch';
$html_retry = 'Nomol';
$html_remember = 'Yystellige spychere';
$html_lang_label = 'Sproch:';
$html_msgperpage_label = 'Nochrichte pro Syte:';
$html_preferences = 'Yystellige';
$html_full_name_label = 'Vollständige Name:';
$html_email_address_label = 'E-Mail-Adräss:';
$html_ccself = 'Kopii vu dr Nochrichte an di eige Adräss schicke';
$html_hide_addresses = 'Adrässe verstecke';
$html_outlook_quoting = 'Quoting im Outlook-Stil';
$html_reply_to = 'Antwort an';
$html_use_signature = 'Signatur verwände';
$html_signature = 'Signatur';
$html_signature_label = 'Unterschrift:';
$html_reply_leadin_label = 'Antwort-Yyleitig:';
$html_prefs_updated = 'Yystellige gspycheret';
$html_manage_folders_link = 'IMAP-Ordner verwalte';
$html_manage_filters_link = 'E-Mail-Filter verwalte';
$html_use_graphical_smilies = 'Graphischi Emoticons verwände';
$html_sent_folder_label = 'Kopier di verschickt E-Mail in s Verzeichnis, wu aagee isch:';
$html_trash_folder_label = 'Gleschti Mail in dr Ordner verschiebe, wu aagee isch:';
$html_colored_quotes = 'Farbigi Zitat';
$html_display_struct = 'Strukturierte Täkscht aazeige';
$html_send_html_mail = 'E-Mail im HTML-Format verschicke';
$html_folders = 'Ordner';
$html_folders_create_failed = 'Dr Ordner het nit chenne aagleit wäre!';
$html_folders_sub_failed = 'Dr Ordner het nit chenne abonniert wäre!';
$html_folders_unsub_failed = 'Dr Ordner het nit chenne abbstellt wäre!';
$html_folders_rename_failed = 'Dr Ordner het nit chenne umgnännt wäre!';
$html_folders_updated = 'D Ordner sin aktualisiert wore';
$html_folder_subscribe = 'Abonniere';
$html_folder_rename = 'Umnänne:';
$html_folder_create = 'Neje Ordner aalege';
$html_folder_remove = 'Abbstelle:';
$html_folder_delete = 'Lesche';
$html_folder_to = 'no';
$html_filter_remove = 'Lesche';
$html_filter_body = 'Nochrichtetäkscht';
$html_filter_subject = 'Beträff';
$html_filter_to = 'Empfängerfäld (To)';
$html_filter_cc = 'Cc-Fäld';
$html_filter_from = 'Absänderfäld (From)';
$html_filter_change_tip = 'Go ne Filter ändere chasch dää eifach iberschrybe.';
$html_reapply_filters = 'Alli Filter nomol aawände';
$html_filter_contains = 'beinhaltet';
$html_filter_name = 'Filter Name';
$html_filter_action = 'Filter Aktion';
$html_filter_moveto = 'Verschiebe no';
$html_select_one = '--Uuswehle--';
$html_and = 'Un';
$html_new_msg_in = 'Neji Nochrichte in';
$html_or = 'oder';
$html_move = 'Verschiebe';
$html_copy = 'Kopiere';
$html_messages_to = 'di markierte Nochrichte no';
$html_gotopage = 'Gang uf d Syte';
$html_gotofolder = 'Gang zum Ordner';
$html_other_folders = 'Ordner Lischt';
$html_page = 'Syte';
$html_of = 'vu';
$html_view_header = 'Header aazeige';
$html_remove_header = 'Header verstecke';
$html_inbox = 'Poschtyygang';
$html_new_msg = 'Schrybe';
$html_reply = 'Antwort gee';
$html_reply_short = 'Re:';
$html_reply_all = 'Antwort an alli';
$html_forward = 'Wyterleitig';
$html_forward_short = 'Fwd:';
$html_forward_info = 'D Nochricht, wu soll wytergleitet wäre, wird mit däre E-Mail as Aahang verschickt.';
$html_delete = 'Lesche';
$html_new = 'Nej';
$html_mark = 'Lesche';
$html_att_label = 'Aahang:';
$html_atts_label = 'Aahäng:';
$html_unknown = '[nit bekannt]';
$html_attach = 'Aahänke';
$html_attach_forget = 'Du muesch d Datei vo em Verschicke vu dr Nochicht aahänke !';
$html_attach_delete = 'Uusgwehlti uuseneh';
$html_attach_none = 'As Aahang muesch e Datei uuswehle!';
$html_sort_by = 'Sortiere no';
$html_sort = 'Sortiere';
$html_from = 'Vu';
$html_from_label = 'Vu:';
$html_subject = 'Beträff';
$html_subject_label = 'Betreff:';
$html_date = 'Datum';
$html_date_label = 'Datum:';
$html_sent_label = 'Gschickt:';
$html_wrote = 'het gschribe';
$html_size = 'Greßi';
$html_totalsize = 'Gsamtgreßi';
$html_kb = 'kB';
$html_mb = 'MB';
$html_gb = 'GB';
$html_bytes = 'Byte';
$html_filename = 'Dateiname';
$html_to = 'An';
$html_to_label = 'An:';
$html_cc = 'Kopii';
$html_cc_label = 'Cc:';
$html_bcc_label = 'Bcc:';
$html_nosubject = 'Kei Beträff';
$html_send = 'Schicke';
$html_cancel = 'Abbräche';
$html_no_mail = 'Kei neji Nochrichte.';
$html_logout = 'Abmälde';
$html_msg = 'Nochricht';
$html_msgs = 'Nochrichte';
$html_configuration = 'Dää Server isch nit richtig konfiguriert!';
$html_priority = 'Priorität';
$html_priority_label = 'Priorität:';
$html_lowest = 'Seli nider';
$html_low = 'Nider';
$html_normal = 'Normal';
$html_high = 'Hoch';
$html_highest = 'Seli hoch';
$html_flagged = 'Markiert';
$html_spam = 'Spam';
$html_spam_warning = 'Die Nochricht isch as Spam klassifiziert wore.';
$html_receipt = 'Läsebstätigung aafordere';
$html_select = 'Uuswahl';
$html_select_all = 'Uuswahl umdrille';
$html_select_contacts = 'Kontakt uuswehle';
$html_loading_image = 'Am Bild lade';
$html_send_confirmed = 'Dyy Mail isch verschickt wore.';
$html_no_sendaction = 'Kei Aktion aagee. Schalt JavaScript yy un versuech s drno nomol.';
$html_error_occurred = 'S het e Fähler gee';
$html_prefs_file_error = 'Cha d Yystellige-Datei nit Ufmache zum Schrybe.';
$html_wrap = 'Zahl vu Zeiche, wu di verschickte Nochrichte derno umbroche wäre:';
$html_wrap_none = 'Kei Umbruch';
$html_usenet_separator = 'Usenet-Signaturtränner ("-- \n") verwände';
$html_mark_as = 'Markier as';
$html_read = 'gläse';
$html_unread = 'nit gläse';
$html_encoding_label = 'Zeichesatz-Kodierig:';
$html_add = 'Zuefiege';
$html_contacts = 'Kontakt vu %1$s';
$html_modify = 'Ändere';
$html_back = 'Zruck';
$html_contact_add = 'Neje Kontakt dezuefiege';
$html_contact_mod = 'E Kontakt ändere';
$html_contact_first = 'Vorname';
$html_contact_last = 'Nochname';
$html_contact_nick = 'Ibername';
$html_contact_mail = 'E-Mail-Adräss';
$html_contact_list = 'Kontaktlischt vu %1$s';
$html_contact_del = 'vu dr Kontaktlischt';
$html_contact_count = '%1$d Kontakt';
$html_contact_err1 = 'D Maximalaazahl vu dr Kontakt isch „%1$d“';
$html_contact_err2 = 'Du chasch kei neje Kontakt dezuefiege';
$html_contact_err3 = 'Du hesch nit s Rächt, uf d Kontaktlischt zuezgryfe';
$html_contact_none = 'Kei Kontakt gfunde.';
$html_del_msg = 'Solle di markierte Nochrichte glescht wäre?';
$html_down_mail = 'Abelade';
$original_msg = '-- Urspringligi Nochricht --';
$to_empty = 'S \'An\'-Fäld derf nit läär syy !';
$html_images_warning = 'Zue Dyynere Sicherheit wäre externi Bilder nit aazeigt.';
$html_images_display = 'Bilder aazeige';
$html_smtp_error_no_conn = 'Het d Verbindung nit chenne ufmache';
$html_smtp_error_unexpected = 'SMTP-Antwort, wu nit erwartet woren isch:';
$lang_could_not_connect = 'Verbindig zum Server fählgschlaa';
$lang_invalid_msg_num = 'Fählerhafti Nochrichte-Nummere';
$html_file_upload_attack = 'D Datei, wu ufeglade woren isch, het nit chenne gfunde wäre';
$html_invalid_email_address = 'Nit giltigi E-Mail-Adräss';
$html_invalid_msg_per_page = 'Nit giltigi Aazahl vu Nochrichte pro Syte.';
$html_invalid_wrap_msg = 'Nit giltige Nochrichtenumbruch';
$html_seperate_msg_win = 'Nochricht in eme neje Fänschter ufmache';
$html_err_file_contacts = 'Cha d Kontaktdatei nit zum Schryben ufmache.';
$html_session_file_error = 'Cha d Sitzigsdatei nit zum Schryben ufmache.';
$html_login_not_allowed = 'Die Aamäldig isch nit zuegloo fir e Verbindig.';
$lang_err_send_delay = 'Du muesch zwische zwoo Mails warte (%1$d seconds)';
$html_search = 'Sueche';
